@@ -222,25 +222,6 @@ class TestValidateInterfacesHookBeforeProcessing(test_base.NodeTest):
         self.assertRaisesRegex(utils.Error, 'No suitable interfaces found',
                                self.hook.before_processing, self.data)
 
-    def test_skipped_interfaces_with_local_address(self):
-        CONF.set_override('add_ports', 'active', 'processing')
-        self.inventory['interfaces'] = [
-            # local interface (by IPv4 address)
-            {'name': 'em1', 'mac_address': '22:22:22:22:22:22',
-             'ipv4_address': '127.0.0.1'},
-            # local interface (by IPv6 address)
-            {'name': 'em2', 'mac_address': '33:33:33:33:33:33',
-             'ipv6_address': '::1'},
-            # interface only with local-link address
-            {'name': 'em3', 'mac_address': '44:44:44:44:44:44',
-             'ipv6_address': 'fe80::4644:44ff:fe44:4444'},
-            # interface only with local-link address with suffix
-            {'name': 'em4', 'mac_address': '55:55:55:55:55:55',
-             'ipv6_address': 'fe80::5755:55ff:fe55:5555%em4'},
-        ]
-        self.assertRaisesRegex(utils.Error, 'No suitable interfaces found',
-                               self.hook.before_processing, self.data)
-
     def test_interfaces_with_ipv6_addresses_only(self):
         CONF.set_override('add_ports', 'all', 'processing')
         self.inventory['interfaces'] = [
@@ -382,6 +363,7 @@ class TestRootDiskSelection(test_base.NodeTest):
             {'model': 'Model 3', 'size': 10 * units.Gi, 'name': '/dev/sdc'},
             {'model': 'Model 4', 'size': 4 * units.Gi, 'name': '/dev/sdd'},
             {'model': 'Too Small', 'size': 1 * units.Gi, 'name': '/dev/sde'},
+            {'model': 'Floppy', 'size': 0, 'name': '/dev/sdf'},
         ]
         self.matched = self.inventory['disks'][2].copy()
         self.node_info = mock.Mock(spec=node_cache.NodeInfo,
@@ -453,6 +435,15 @@ class TestRootDiskSelection(test_base.NodeTest):
         self.assertEqual(10, self.data['local_gb'])
         self.node_info.update_properties.assert_called_once_with(local_gb='10')
 
+    def test_zero_size(self):
+        self.node.properties['root_device'] = {'name': '/dev/sdf'}
+
+        self.hook.before_update(self.data, self.node_info)
+
+        self.assertEqual(self.inventory['disks'][5], self.data['root_disk'])
+        self.assertEqual(0, self.data['local_gb'])
+        self.node_info.update_properties.assert_called_once_with(local_gb='0')
+
     def test_all_match(self):
         self.node.properties['root_device'] = {'size': 10,
                                                'model': 'Model 3'}
